
=History

This layout was basically designed for the German Perl Workshop CDs
and was modified for the Perlpoint home page.

Content is formatted via
CSS. Navigation is reduced to small areas but powerful. Additional
to the links, JavaScript navigation via "n", space bar and "p" is
provided.

The original layout embeds archives and a search engine. These parts
were removed from this example.

