
=History

This layout was designed for the German Perl Workshop CDs and is
still used there. This layout is an alternative to the traditional
frame based design with Java applet navigation, intended to reflect
modern HTML.

So, as a result, everything is displayed in one page, formatted via
CSS. Navigation is reduced to small areas but powerful. Additional
to the links, JavaScript navigation via "n", space bar and "p" is
provided.

The original layout embeds archives and a search engine. These parts
were removed from this example.


=Note

If you are interested in automated conference CD production, please
have a look at \L{url="http://www.sf.net/projects/perlpoint"}<PerlPointCD>.

