
<CENTER>

<div id=title style="padding:15px">
  <table border="0" cellspacing="2" cellpadding="0">
  <tbody>
    <tr>
      <td style="font-size:xx-small"><i>PAGE_PATH</i></td>
    </tr>
  </tbody>
  </table>
</div>

<TABLE bgcolor="yellow"> 
<TR>
 <TD colspan=3 style="font-size:xx-small">
    Next: <a href="URL_NEXT">TXT_NEXT</a>
    &nbsp;&nbsp;
    Previous: <a href="URL_PREV">TXT_PREV</a>
    &nbsp;&nbsp;
    Index: REF(, Index, Index)
 </td>
</TR>
</TABLE>

</CENTER>



