
=Description

This is a demo PerlPoint style to produce S5 presentations from
PerlPoint sources. S5 is a presentation format designed by Eric
Meyer. Please search the Web for details.

Technically, this is an example of how to use the Template Toolkit
to write PerlPoint styles.

To learn about this style please see the \C<overview.pp> document
in this doc chapter. Then, as an example, you might try to produce
an S5 presentation from it ;-)