
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">

<html>

<head>

  FAVICON_LINKTAG

  LINK_NAVIGATION

  DOC_METATAGS

  <title>DOCTITLE</title>

</head>

<frameset border=0 frameborder=0 framespacing=0 rows="75, *, 65">

   <noframes>

    <center>

    <p>
    This site uses frames. Please activate them in your browser.

    </center>

   </noframes>

    <frame src="./PREFIX-topfSUFFIX" name="Top">
    <frameset border=0 frameborder=0 framespacing=0 cols="320, *">
      <frame src="PREFIX-tocSUFFIX" name="Index">
      <frame src="PREFIX-1SUFFIX" name="Data">
    </frameset>
    <frame src="./PREFIX-botfSUFFIX" name="Foot">
</frameset>

<body>
  Please call the <a href="PREFIX-1SUFFIX">title page</a>
</body>

</html> 
