
// This file is intended to document in detail. It does not repeat the overview file
// but continues it.


=Directory structure

The example style shows the subdirectories that a new PerlPoint style is made of:

* \C<cfg> - for option files,

* \C<templates> - for template files,

* \C<doc> - for documentation (usually overview.pp and description.pp),

* \C<lib> - for own generator, formatter or template modules,

* \C<images> - for screenshots and the like.


=Navigation

The style includes four navigation methods:

* Applet: the leftmost frame contains an Java applet to navigate through the
  chapters.

* Header and footer links: each page contains a navigation bar with links to the
  next and previous chapter, and to the index page.

* Path: for all chapters below the main level, a path navigation link appears
  right above the top navigation bar, to enter any parent level.

* JavaScript: special keys switch to the next or previous page: use space bar,
  "n" or a click onto the page to enter the next page, or use "p" to go back.

