
</div>
<!-- content -->
</div>
<!-- row -->
</div>
<!-- cd -->


<div id=footer>

 <span class=pp>
 <a href="http://www.sourceforge.net/projects/perlpoint">PerlPoint</a> powered.
 </span>


 <span class=copy> Copyright &copy; 2005 <a
 href="http://www.sf.net/projects/perlpoint">Jochen Stenzel</a>. <br>
 <span class=rights>All rights reserved.</span> </span>

</div>
<!-- end footer -->

