
<div id=header>

<div id=title>
  <table border="0" cellspacing="2" cellpadding="0" width="100%">
  <tbody>
    <tr>
      <td width="15%"></td>
      <td align=center>DOCTITLE<br><i>PAGE_PATH</i></td>
    </tr>
  </tbody>
  </table>
</div>
<!-- end title -->

</div>
<!-- end header -->

<div id=cd>
<div id=row>
<div id="nav">

<table border="0" cellspacing="0" cellpadding="0" width="100%">
  <tbody>
    <tr>
      <td>
        <table>
          OPT(validate, <tr><td>DATE(%c).</td></tr><tr><td>&nbsp;</td></tr><tr><td>Validate <a href="http://validator.w3.org/check/referer">HTML</a>, <a href="http://jigsaw.w3.org/css-validator/check/referer">CSS</a>, <a href="http://validator.w3.org/checklink?uri=START_ADDRESS/URL_HERE">Links</a>.</td></tr>)
          <tr><td>&nbsp;</td></tr>
	  <tr><td>? <a href="URL_INDEX">TXT_INDEX</a></td></tr>
	  <tr><td>&nbsp;</td></tr>
        </table>
     </td>
   </tr>
</table>

<div class=badcss><blockquote>triggered .badcss&gt;blockquote</blockquote>
</div>

</div>
<!-- end nav -->


<div id="content">

<blockquote class="ahem">You are using a browser which doesn't fully support
  Cascading Style Sheets. This site will look <em>much</em> better in a browser that
  supports <a href="http://www.webstandards.org/" target="_blank">web standards</a>,
  but its content is accessible to any browser or Internet device.
</blockquote>

<!-- "<span><div><blockquote>triggered span&gt;div&gt;blockquote</blockquote></div></span>" -->


