<HTML>
<BODY bgcolor="yellow">

<TABLE WIDTH=100%  BORDER=0 CELLSPACING=0 CELLPADDING=2>
<TR>
 <TD ALIGN=left border=0>
    <a href="http://www.sourceforge.net/projects/perlpoint" target=_new border=0><image src="PPL13s5b-o.jpg" border=0 alt="PerlPoint powered"></a> 
 </TD>
 <TD VALIGN=top ALIGN=right ><SMALL>
    Copyright &copy; 
    <a href="http://www.sf.net/projects/perlpoint" target=_new>Jochen Stenzel, DATE(%Y)</a>.<BR> All rights reserved.
    </SMALL>
 </TD>
</TR>
</TABLE>

