<!-- Header template file -->

<!-- CSS link tags -->
CSS_LINKTAGS

<!-- link navigation -->
LINK_NAVIGATION

<!-- document info meta tags -->
DOC_METATAGS

<!-- title -->
<title>TITLE</title>

<LINK REL="stylesheet" TYPE="text/css" HREF="basic.css">

<style type="text/css" media="all">
  @import "ahem.css";
  @import "main.css";
  /* e.g. IE 5.x on the Mac does not understand the following */
  span>div>blockquote { display: none; height: 0; }
  .badcss { display: none; height: 0; }
  .badcss>blockquote { display: none; height: 0; }
</style>

<style type="text/css">
  .bga  { background-color: #aaaaff; text-align: center;}
  .bgb  { background-color: #bbbbff; text-align: center;}
  .bgc  { background-color: #ccccff; text-align: center;}
  .bgd  { background-color: #ddddff; text-align: center;}
  .bge  { background-color: #eeeeff; text-align: center;}
  .bgf  { background-color: #ffff99; text-align: center;}
  .slack { border: 3px double #bbbbbb;}
  .vrule { position: absolute; right: 0px; top: 1px; }
</style>



