
// A short overview of the style, with all the informations required to quick start.
// The complete documentation is made of this file and description.pp.


=A sample style

This is an example of a PerlPoint style, intended to be used with a PerlPoint generator.

It emulates one of the traditional \C<pp2html> styles: a frame based layout with a tree
applet for navigation in the leftmost frame.


=Requirements

To use this style, you need to have \C<PerlPoint::Template::Traditional> installed.


=Third party code included

The CSS parts of the templates are derived from style sheets designed
by Jrgen Christoffel. Used with permission.

The JavaScript navigation code is copied from Brian Ingersons Kwiki software and used according
to Kwikis license.

The files in the \C<templates/applet_src> directory build the free version 1 of the Java "TreeApplet".
This software was available on the net a few years ago, was followed by a commercial version 2, and
finally disappeared.

.\B<USE THIS SOFTWARE ON YOUR OWN RISK. THIS SOFTWARE IS NO PART OF PerlPoint::styles
AND HAS ITS OWN LICENSE: AS FAR AS I KNOW, THIS VERSION WAS FREE. IF YOU ARE
IN DOUBT, PLEASE USE ANOTHER NAVIGATION APPLET OR JAVASCRIPT.>


=License

The style can be used under the same conditions as \C<PerlPoint::styles> itself.




