
<CENTER>
<TABLE bgcolor="yellow"> 
<TR>
 <TD colspan=3 style="font-size:xx-small">
   <center>
    Next: <a href="URL_NEXT">TXT_NEXT</a>
    &nbsp;&nbsp;Previous: <a href="URL_PREV">TXT_PREV</a>
    &nbsp;&nbsp;Index: REF(, Index, Index)
    <br>
    Page version VAR(docVersion), produced: VAR(docDate). Autor(s): <a href="mailto:VAR(docAuthorMail)">VAR(docAuthor)</a>
   </center>
 </td>
</TR>
</TABLE>
</CENTER>
