
// the overview part of the style doc

=Intro

This is an example PerlPoint style, part of \C<PerlPoint::styles>.
It demonstrates a CSS based layout.

The layout shown is derived from a real world layout, basically
designed by Jrgen Christoffel for the CDs of the German Perl
Workshop and used with permission.


=Requirements

To use this style, you need to have \C<PerlPoint::Template::Traditional> installed.


=Features

* Two column design with navigation and contents columns,
  separated by a blue dotted line.

* Header and footer regions.

* Column lengths automatically adapted to the contents.

* Linked path navigation in the header.

* Modern, clear and contents focussed.

* Written for modern browsers, but taking care of older models
  by notifying their users.


=License

This style can be used under the same terms as \C<PerlPoint::styles>
itself. Derived layouts should document their heritage.

